import{C as a}from"./gateway.dd2bcb1f.js";import"./index.f0b92b7e.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="5f7c7f2a-639e-490a-afee-37d8c02599b1",r._sentryDebugIdIdentifier="sentry-dbid-5f7c7f2a-639e-490a-afee-37d8c02599b1")}catch{}})();class d{async list(e){return a.get(`organizations/${e}/folders`)}async create(e){return a.post(`organizations/${e.organizationId}/folders`,{name:e.name,memberIds:e.memberIds})}async delete(e,n){return a.delete(`organizations/${e}/folders/${n}`)}async update(e,n){return a.patch(`organizations/${e}/folders/${n.id}/`,{name:n.name,memberIds:n.memberIds})}}export{d as F};
//# sourceMappingURL=folder.76290bf8.js.map
