import{n as t,a as i}from"./string.1b82e875.js";import"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="c390e1c5-74c3-4c50-a908-3b98487dc024",e._sentryDebugIdIdentifier="sentry-dbid-c390e1c5-74c3-4c50-a908-3b98487dc024")}catch{}})();function o(e){return e.replace(/\.py$/,"").trim().length===0?{valid:!1,reason:"File name cannot be empty"}:e.length>255?{valid:!1,reason:"File name cannot be longer than 255 characters"}:e.endsWith(".py")?{valid:!0}:{valid:!1,reason:"File name must end with .py"}}function u(e){if(!o(e).valid)throw new Error("Invalid filename");const n=e.slice(0,-3);return t(n,!0,!0,!0,!0)+".py"}function c(e){return t(e,!0,!0,!0,!0)+".py"}function s(e){return e.trim().length===0?{valid:!1,reason:"Path cannot be empty"}:{valid:!0}}function f(e){if(!s(e).valid)throw new Error("Invalid path");return e.split("/").filter(Boolean).map(r=>i(r)).join("/")}export{s as a,c as b,u as c,f as n,o as v};
//# sourceMappingURL=validations.6db20a24.js.map
