import{d as i,o as p,c as n,w as a,b as m,u as t}from"./index.f0b92b7e.js";import"./linters.c97d2b7c.js";import{W as s}from"./workspaces.45d829e9.js";import{C as d}from"./ContentLayout.728ae941.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.3165243c.js";import"./asyncComputed.451e9a72.js";import"./workspaceStore.ad60b079.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";import"./record.aae20370.js";import"./gateway.dd2bcb1f.js";import"./popupNotifcation.1a1aff4d.js";import"./fetch.d7470d5a.js";import"./SaveButton.1003d0c7.js";import"./UnsavedChangesHandler.6b99a65e.js";import"./ExclamationCircleOutlined.7ab24bca.js";import"./CrudView.fdf2a3ee.js";import"./router.b636156b.js";import"./Badge.503c1d1d.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a2d15d8f.js";import"./BookOutlined.109c3ef4.js";import"./PhDotsThreeVertical.vue.0215e6b6.js";import"./index.26805589.js";import"./index.33db5ee2.js";import"./polling.9459178b.js";import"./PhPencil.vue.8b609b8e.js";import"./index.a71dc8cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d34bad84-6c7f-49c1-a067-54b1fd51749a",o._sentryDebugIdIdentifier="sentry-dbid-d34bad84-6c7f-49c1-a067-54b1fd51749a")}catch{}})();const G=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(p(),n(d,null,{default:a(()=>[m(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(s)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{G as default};
//# sourceMappingURL=EnvVarsEditor.a2c8016d.js.map
