import{d as f,o as s,c as d,w as a,b as n,$ as l,S as r,u as o,dj as i,ey as p,e8 as c,bT as y,ez as b,aW as g}from"./index.f0b92b7e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="ed5f75cc-6623-41aa-83dd-e9d520a234bd",t._sentryDebugIdIdentifier="sentry-dbid-ed5f75cc-6623-41aa-83dd-e9d520a234bd")}catch{}})();const k=f({__name:"AbstraButton",props:{disabledTooltip:{},prefixCls:{},type:{},htmlType:{},shape:{},size:{},loading:{type:[Boolean,Object]},disabled:{type:Boolean},ghost:{type:Boolean},block:{type:Boolean},danger:{type:Boolean},icon:{},href:{},target:{},title:{},onClick:{type:[Function,Array]},onMousedown:{type:[Function,Array]}},setup(t){return(e,u)=>!e.disabledTooltip||!e.disabled?(s(),d(o(y),p(c({key:0},e.$props)),{default:a(()=>[n(o(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[e.loading?r("",!0):l(e.$slots,"default",{key:0})]),_:3})]),_:3},16)):(s(),d(o(g),{key:1,title:e.disabledTooltip},{default:a(()=>[n(o(y),p(b(e.$props)),{default:a(()=>[n(o(i),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:a(()=>[e.loading?r("",!0):l(e.$slots,"default",{key:0})]),_:3})]),_:3},16)]),_:3},8,["title"]))}});export{k as _};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.966e6b97.js.map
