import{_ as m}from"./TasksView.vue_vue_type_script_setup_true_lang.a4c63a05.js";import{R as f}from"./tasksController.3c17e23f.js";import{d as b,ea as _,f as y,o as n,Y as g,b as w,w as k,u as c,c as I,S as T,aS as v,aG as B,df as S}from"./index.f0b92b7e.js";import"./gateway.dd2bcb1f.js";import{a as j,B as x}from"./build.e0c06e13.js";import{a as C}from"./project.30b2603f.js";import"./tables.cf074385.js";import{a as D}from"./asyncComputed.451e9a72.js";import"./metadata.b17b5a4e.js";import"./PhWebhooksLogo.vue.4b8dd4f2.js";import"./string.1b82e875.js";import"./ant-design.0728f411.js";import"./dayjs.15e0cd57.js";import"./index.26805589.js";import"./polling.9459178b.js";import"./scripts.bf6689bc.js";import"./record.aae20370.js";import"./linters.c97d2b7c.js";import"./popupNotifcation.1a1aff4d.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="e91bce6d-89bd-4cbc-a71a-bc78e058c895",e._sentryDebugIdIdentifier="sentry-dbid-e91bce6d-89bd-4cbc-a71a-bc78e058c895")}catch{}})();const Q=b({__name:"Tasks",setup(e){const a=_().params.projectId,l=new f(a),{result:o}=D(async()=>{const r=(await j.list(a)).find(d=>d.latest);if(!r)return null;const[p,u]=await Promise.all([x.get(r.id),C.get(a)]);return{buildSpec:p,project:u}}),i=y(()=>!o.value||!o.value.buildSpec?null:o.value.buildSpec.runtimes.map(t=>({id:t.id,stageTitle:t.title,stageType:t.type})));return(t,r)=>(n(),g(v,null,[w(c(S),null,{default:k(()=>[B("Tasks")]),_:1}),i.value?(n(),I(m,{key:0,class:"tasks",api:c(l),stages:i.value},null,8,["api","stages"])):T("",!0)],64))}});export{Q as default};
//# sourceMappingURL=Tasks.bf737a47.js.map
