import{k as i,T as n,m as r,P as o,C as d,M as p,s as f,n as s,p as c,q as m,t as u,v as g}from"./index.f0b92b7e.js";import{s as y,c as l,a}from"./workspaceStore.ad60b079.js";import{_ as b}from"./App.vue_vue_type_style_index_0_lang.4369cb54.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";import"./PlayerConfigProvider.1d7c2ccb.js";import"./index.a92924fd.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="d3029636-17f3-4b76-9ad3-d9faa4fa8316",t._sentryDebugIdIdentifier="sentry-dbid-d3029636-17f3-4b76-9ad3-d9faa4fa8316")}catch{}})();class w{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=i({render:()=>c(b)});n.init(),r(e,a),w.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",d),e.component("Markdown",p),e.component("Message",f),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.06f9e243.js.map
