import"./App.vue_vue_type_style_index_0_lang.4369cb54.js";import{_ as c}from"./App.vue_vue_type_style_index_0_lang.4369cb54.js";import"./workspaceStore.ad60b079.js";import"./index.f0b92b7e.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";import"./PlayerConfigProvider.1d7c2ccb.js";import"./index.a92924fd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="15a03eb6-cfb5-4883-991f-c6e0001bfaa8",e._sentryDebugIdIdentifier="sentry-dbid-15a03eb6-cfb5-4883-991f-c6e0001bfaa8")}catch{}})();export{c as default};
//# sourceMappingURL=App.2a077769.js.map
