import"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[r]="a69ae4a8-2d6e-46c1-a4a5-6c5bf49d96e2",e._sentryDebugIdIdentifier="sentry-dbid-a69ae4a8-2d6e-46c1-a4a5-6c5bf49d96e2")}catch{}})();const d=e=>{try{return new URL(e),!0}catch{return!1}},o=(e,r)=>{if(!Object.keys(r).length)return e;const t=new URL(e),a=new URLSearchParams(t.search);return Object.entries(r).forEach(([n,s])=>{t.searchParams.delete(n),a.set(n,s)}),`${t.origin}${t.pathname}?${a.toString()}`};export{d as i,o as m};
//# sourceMappingURL=url.a5f3da23.js.map
