.center[data-v-e1b117c5]{display:flex;align-items:center}[data-v-e1b117c5] .ant-tree-treenode{padding:0}[data-v-e1b117c5] .ant-tree-switcher{width:12px}.tasks-manager[data-v-f5e9bb62]{overflow:auto}.v-leave-to[data-v-f5e9bb62],.v-enter-from[data-v-f5e9bb62]{transition:all .4s;opacity:0;position:absolute;width:100%;transform:scale(.5)}.v-enter-to[data-v-f5e9bb62],.v-leave-from[data-v-f5e9bb62]{transition:all .4s;opacity:1;transform:scale(1)}
