import{_ as n}from"./TasksView.vue_vue_type_script_setup_true_lang.a4c63a05.js";import{L as i}from"./tasksController.3c17e23f.js";import{d as p,o as c,c as d,w as a,b as o,aG as _,u as s,df as m,a0 as l}from"./index.f0b92b7e.js";import{C as f}from"./ContentLayout.728ae941.js";import"./metadata.b17b5a4e.js";import"./PhWebhooksLogo.vue.4b8dd4f2.js";import"./string.1b82e875.js";import"./ant-design.0728f411.js";import"./dayjs.15e0cd57.js";import"./index.26805589.js";import"./gateway.dd2bcb1f.js";import"./popupNotifcation.1a1aff4d.js";import"./polling.9459178b.js";import"./scripts.bf6689bc.js";import"./record.aae20370.js";import"./linters.c97d2b7c.js";import"./asyncComputed.451e9a72.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="49b04099-7238-4287-ad22-1047da8cec46",t._sentryDebugIdIdentifier="sentry-dbid-49b04099-7238-4287-ad22-1047da8cec46")}catch{}})();const u=p({__name:"Tasks",setup(t){const e=new i;return(r,y)=>(c(),d(f,null,{default:a(()=>[o(s(m),null,{default:a(()=>[_("Tasks")]),_:1}),o(n,{class:"tasks",api:s(e),stages:null,editor:""},null,8,["api"])]),_:1}))}});const G=l(u,[["__scopeId","data-v-10aa4cc9"]]);export{G as default};
//# sourceMappingURL=Tasks.64220833.js.map
