import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.3165243c.js";import{d as i,ea as s,o as a,c as m,u as f}from"./index.f0b92b7e.js";import"./gateway.dd2bcb1f.js";import"./popupNotifcation.1a1aff4d.js";import"./fetch.d7470d5a.js";import"./record.aae20370.js";import"./SaveButton.1003d0c7.js";import"./UnsavedChangesHandler.6b99a65e.js";import"./ExclamationCircleOutlined.7ab24bca.js";import"./CrudView.fdf2a3ee.js";import"./router.b636156b.js";import"./Badge.503c1d1d.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.a2d15d8f.js";import"./BookOutlined.109c3ef4.js";import"./url.a5f3da23.js";import"./PhDotsThreeVertical.vue.0215e6b6.js";import"./index.26805589.js";import"./index.33db5ee2.js";import"./asyncComputed.451e9a72.js";import"./polling.9459178b.js";import"./PhPencil.vue.8b609b8e.js";import"./index.a71dc8cb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="ea012f50-9425-4f34-9f3f-0566da3668b5",o._sentryDebugIdIdentifier="sentry-dbid-ea012f50-9425-4f34-9f3f-0566da3668b5")}catch{}})();const A=i({__name:"EnvVars",setup(o){const t=s().params.projectId,e=new p(t);return(d,c)=>(a(),m(n,{"env-var-repository":f(e),mode:"console"},null,8,["env-var-repository"]))}});export{A as default};
//# sourceMappingURL=EnvVars.6d8e438a.js.map
