import{O as r}from"./workspaceStore.ad60b079.js";import{d as l,X as i,o as c,Y as u,b as t,w as o,u as n,aG as d,df as f,de as _}from"./index.f0b92b7e.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="dc12a428-b2cc-4a80-a628-d3a0699a6f7d",e._sentryDebugIdIdentifier="sentry-dbid-dc12a428-b2cc-4a80-a628-d3a0699a6f7d")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new r().logoutCallback()}),(a,s)=>(c(),u("div",null,[t(n(f),null,{default:o(()=>[d("You're authenticated")]),_:1}),t(n(_),null,{default:o(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.5ea85df8.js.map
