import{_ as l}from"./Login.vue_vue_type_script_setup_true_lang.e26664ce.js";import{d as m,eo as f,ea as b,o as g,Y as y,b as w,u as n,a0 as k}from"./index.f0b92b7e.js";import{u as h}from"./workspaceStore.ad60b079.js";import"./Logo.69d78281.js";import"./string.1b82e875.js";import"./CircularLoading.765edb2a.js";import"./index.a92924fd.js";import"./index.a71dc8cb.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="cdee24a8-2399-45bb-8530-ca28da5d8650",e._sentryDebugIdIdentifier="sentry-dbid-cdee24a8-2399-45bb-8530-ca28da5d8650")}catch{}})();const v={class:"runner"},I=m({__name:"Login",setup(e){const o=f(),a=b(),t=h(),_=async()=>{const{redirect:r,...s}=a.query;if(r){await o.push({path:r,query:s,params:a.params});return}o.push({name:"playerHome",query:s})};return(r,s)=>{var c,d,p,u,i;return g(),y("div",v,[w(l,{"logo-url":(d=(c=n(t).state.workspace)==null?void 0:c.logoUrl)!=null?d:void 0,"brand-name":(p=n(t).state.workspace)==null?void 0:p.brandName,locale:(i=(u=n(t).state.workspace)==null?void 0:u.language)!=null?i:"en",onDone:_},null,8,["logo-url","brand-name","locale"])])}}});const H=k(I,[["__scopeId","data-v-ce854d6f"]]);export{H as default};
//# sourceMappingURL=Login.b1a2b452.js.map
