import{O as r}from"./workspaceStore.ad60b079.js";import{d as i,X as l,o as u,Y as c,b as a,w as n,u as o,aG as d,df as f,de as _}from"./index.f0b92b7e.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="775a3235-7f14-477a-8483-08d66dad3251",e._sentryDebugIdIdentifier="sentry-dbid-775a3235-7f14-477a-8483-08d66dad3251")}catch{}})();const b=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(t,s)=>(u(),c("div",null,[a(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),a(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{b as default};
//# sourceMappingURL=OidcLoginCallback.c8b51575.js.map
