import{d as l,eh as c,f as d,o as t,Y as a,S as r,e9 as _,a0 as p}from"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="9dd377ee-044f-4a14-bd41-debc149a924e",e._sentryDebugIdIdentifier="sentry-dbid-9dd377ee-044f-4a14-bd41-debc149a924e")}catch{}})();const u={class:"logo"},f=["src","alt"],g={key:1},b=l({__name:"Logo",props:{imageUrl:{},brandName:{},hideText:{type:Boolean},size:{}},setup(e){const s=e;c(o=>({bb5bcf84:n.value}));const n=d(()=>s.size==="small"?"24px":s.size==="large"?"80px":"50px"),i=d(()=>`${s.brandName} Logo`);return(o,m)=>(t(),a("div",u,[o.imageUrl?(t(),a("img",{key:0,class:"logo-img",src:o.imageUrl,alt:i.value},null,8,f)):r("",!0),o.hideText?r("",!0):(t(),a("span",g,_(o.brandName),1))]))}});const h=p(b,[["__scopeId","data-v-8d11f0bb"]]);export{h as L};
//# sourceMappingURL=Logo.69d78281.js.map
