import{U as d,dA as c,dB as i}from"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="a5b46bca-d4ab-4929-8eab-1bde4b028962",e._sentryDebugIdIdentifier="sentry-dbid-a5b46bca-d4ab-4929-8eab-1bde4b028962")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:a,YearPicker:b,TimePicker:m,QuarterPicker:r,RangePicker:o}=c(i),u=d(n,{WeekPicker:t,MonthPicker:a,YearPicker:b,RangePicker:o,TimePicker:m,QuarterPicker:r,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(a.name,a),e.component(t.name,t),e.component(r.name,r),e)});export{u as D,a as M,r as Q,o as R,t as W};
//# sourceMappingURL=dayjs.15e0cd57.js.map
