.description[data-v-b2ed6a6d]{margin-bottom:20px;font-style:italic;display:block}.center[data-v-1cb215a9]{display:flex;flex-direction:column;width:100%}.form-preview[data-v-1cb215a9]{display:flex;flex-direction:column;height:100%;overflow:hidden;box-sizing:border-box}.form-preview-container[data-v-1cb215a9]{display:flex;flex-direction:column;justify-content:center;align-items:center;border-radius:4px;overflow:hidden;height:100%;position:relative}.runner[data-v-1cb215a9]{flex-grow:1;overflow:hidden}.unsaved-changes[data-v-1cb215a9]{position:absolute;z-index:1}.form-settings[data-v-aff64cb2]{height:100%;overflow:auto;box-sizing:border-box;padding:0 0 20px}
