import{L as t}from"./Logo.69d78281.js";import{d as n,o as r,c as d,u as a}from"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="2db72186-7d67-4366-9790-c4de14782442",e._sentryDebugIdIdentifier="sentry-dbid-2db72186-7d67-4366-9790-c4de14782442")}catch{}})();const i="/assets/logo.0faadfa2.svg",c=n({__name:"AbstraLogo",props:{hideText:{type:Boolean},size:{}},setup(e){return(o,s)=>(r(),d(t,{"image-url":a(i),"brand-name":"Abstra","hide-text":o.hideText,size:o.size},null,8,["image-url","hide-text","size"]))}});export{c as _};
//# sourceMappingURL=AbstraLogo.vue_vue_type_script_setup_true_lang.26ffa16c.js.map
