import{d as a,o,Y as s,b as d,u as r,by as _,a0 as i}from"./index.f0b92b7e.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="e3f6659b-7fe3-4d85-96a3-0f89756ea55e",e._sentryDebugIdIdentifier="sentry-dbid-e3f6659b-7fe3-4d85-96a3-0f89756ea55e")}catch{}})();const c={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",c,[d(r(_))]))}});const u=i(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.342f3479.js.map
