import{P as m}from"./PlayerNavbar.015aba66.js";import{d as g,eo as h,ea as i,e as b,f as y,r as k,o as c,Y as v,u as n,c as w,S as L,a as C,b as I,a0 as N}from"./index.f0b92b7e.js";import{u as V}from"./workspaceStore.ad60b079.js";import"./metadata.b17b5a4e.js";import"./PhWebhooksLogo.vue.4b8dd4f2.js";import"./LoadingOutlined.67ec2f2e.js";import"./PhSignOut.vue.473b638b.js";import"./index.38fab6db.js";import"./Avatar.e9d19919.js";import"./url.a5f3da23.js";import"./colorHelpers.4c8a49fb.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[e]="9fa40738-ba32-4e3f-a164-b4ab90330f69",o._sentryDebugIdIdentifier="sentry-dbid-9fa40738-ba32-4e3f-a164-b4ab90330f69")}catch{}})();const x={class:"main-container"},B={class:"content"},D=g({__name:"Main",setup(o){const e=h(),t=V(),u=i().path,a=b(null),d=async({path:s,id:r})=>{a.value=r,await e.push({path:`/${s}`}),a.value=null},l=()=>{e.push({name:"playerLogin"})},p=()=>{e.push({name:"playerLogin"})},_=y(()=>!!i().meta.hideLogin);return(s,r)=>{const f=k("RouterView");return c(),v("div",x,[n(t).state.workspace?(c(),w(m,{key:0,"current-path":n(u),"hide-login":_.value,"runner-data":n(t).state.workspace,loading:a.value,onNavigate:d,onLoginClick:p,onLogoutClick:l},null,8,["current-path","hide-login","runner-data","loading"])):L("",!0),C("section",B,[I(f)])])}}});const A=N(D,[["__scopeId","data-v-f095bece"]]);export{A as default};
//# sourceMappingURL=Main.d8964018.js.map
