import{b as r,u as n}from"./workspaceStore.ad60b079.js";import{W as c}from"./PlayerConfigProvider.1d7c2ccb.js";import{d,g as i,r as p,u as o,o as u,c as f,w as l,S as _,b as m}from"./index.f0b92b7e.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="bcae342d-e615-4be3-93dc-41a7479e7987",t._sentryDebugIdIdentifier="sentry-dbid-bcae342d-e615-4be3-93dc-41a7479e7987")}catch{}})();const h=d({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),i(()=>a.jwt,e.actions.fetch),(w,y)=>{const s=p("RouterView");return o(e).state.workspace?(u(),f(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:l(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):_("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.4369cb54.js.map
